OME-NGFF (OME-Zarr)
===================

.. module:: iohub

Convenience
-----------

`open_ome_zarr`
^^^^^^^^^^^^^^^
.. autofunction:: open_ome_zarr


NGFF Nodes
----------

.. currentmodule:: iohub.ngff


`NGFFNode`
^^^^^^^^^^

.. autoclass:: NGFFNode
    :members:

`Position`
^^^^^^^^^^
.. autoclass:: Position
    :members:


`TiledPosition`
^^^^^^^^^^^^^^^
.. autoclass:: TiledPosition
    :members:

`Plate`
^^^^^^^
.. autoclass:: Plate
    :members:
